Error during scraping — Python documentation

Note

Click here to download the full example code or to run this example in your browser via Binder

# Error during scraping

The error is actually introduced by the resetter in `conf.py`. It mocks a “zero-size reduction” error in `fig.savefig`.

    import matplotlib.pyplot as plt
    fig = plt.figure()

Total running time of the script: ( 0 minutes 0.000 seconds)

Gallery generated by Sphinx-Gallery